#
# spec file for package plasma6-systemmonitor
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf6_version 6.10.0
%define qt6_version 6.7.0

%define rname plasma-systemmonitor

%bcond_without released
# Full Plasma 6 version (e.g. 6.0.0)
%{!?_plasma6_bugfix: %define _plasma6_bugfix %{version}}
# Latest ABI-stable Plasma (e.g. 6.0 in KF6, but 6.0.80 in KUF)
%{!?_plasma6_version: %define _plasma6_version %(echo %{_plasma6_bugfix} | awk -F. '{print $1"."$2}')}
Name:           plasma6-systemmonitor
Version:        6.3.3
Release:        1.1
Summary:        An application for monitoring system resources
License:        GPL-3.0-only
URL:            https://www.kde.org
Source0:        https://download.kde.org/stable/plasma/%{version}/%{rname}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/plasma/%{version}/%{rname}-%{version}.tar.xz.sig
Source2:        plasma.keyring
%endif
BuildRequires:  fdupes
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  update-desktop-files
BuildRequires:  cmake(KF6Config) >= %{kf6_version}
BuildRequires:  cmake(KF6Crash) >= %{kf6_version}
BuildRequires:  cmake(KF6DBusAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6GlobalAccel) >= %{kf6_version}
BuildRequires:  cmake(KF6I18n) >= %{kf6_version}
BuildRequires:  cmake(KF6ItemModels) >= %{kf6_version}
BuildRequires:  cmake(KF6KIO) >= %{kf6_version}
BuildRequires:  cmake(KF6KirigamiAddons)
BuildRequires:  cmake(KF6NewStuff) >= %{kf6_version}
BuildRequires:  cmake(KF6Package) >= %{kf6_version}
BuildRequires:  cmake(KF6Service) >= %{kf6_version}
BuildRequires:  cmake(KSysGuard) >= %{_plasma6_bugfix}
BuildRequires:  cmake(Qt6DBus) >= %{qt6_version}
BuildRequires:  cmake(Qt6Quick) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
Requires:       kf6-kiconthemes-imports >= %{kf6_version}
Requires:       kf6-kirigami-imports >= %{kf6_version}
Requires:       kf6-kitemmodels-imports >= %{kf6_version}
Requires:       kf6-knewstuff-imports >= %{kf6_version}
Requires:       kf6-kquickcharts >= %{kf6_version}
Requires:       kf6-qqc2-desktop-style >= %{kf6_version}
Requires:       kirigami-addons6
Requires:       ksystemstats6 >= %{_plasma6_bugfix}
Requires:       qt6-declarative-imports >= %{qt6_version}
Provides:       plasma5-systemmonitor = %{version}
Obsoletes:      plasma5-systemmonitor < %{version}
Obsoletes:      plasma5-systemmonitor-lang < %{version}

%description
plasma-systemmonitor provides an interface for monitoring system sensors,
process information and other system resources.

%lang_package

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
%cmake_kf6

%kf6_build

%install
%kf6_install

%suse_update_desktop_file org.kde.plasma-systemmonitor System Monitor

%fdupes %{buildroot}%{_kf6_sharedir}

%find_lang %{name} --all-name

%ldconfig_scriptlets

%files
%license LICENSES/*
%doc README.md
%{_kf6_applicationsdir}/org.kde.plasma-systemmonitor.desktop
%{_kf6_appstreamdir}/org.kde.plasma-systemmonitor.metainfo.xml
%{_kf6_bindir}/plasma-systemmonitor
%{_kf6_configkcfgdir}/systemmonitor.kcfg
%{_kf6_knsrcfilesdir}/plasma-systemmonitor.knsrc
# FIXME result of 105cb99d & bb8d4048
%{_kf6_libdir}/libPlasmaSystemMonitorPage.so
%{_kf6_libdir}/libPlasmaSystemMonitorTable.so
%dir %{_kf6_qmldir}/org/kde/ksysguard/
%{_kf6_qmldir}/org/kde/ksysguard/page/
%{_kf6_qmldir}/org/kde/ksysguard/table/
%dir %{_kf6_sharedir}/ksysguard/
%{_kf6_sharedir}/ksysguard/sensorfaces/
%{_kf6_sharedir}/plasma-systemmonitor/
%dir %{_kf6_sharedir}/kconf_update/
 %{_kf6_sharedir}/kconf_update/plasma-systemmonitor-replace-vmpss.py
 %{_kf6_sharedir}/kconf_update/plasma-systemmonitor.upd
%dir %{_kf6_sharedir}/plasma/kinfocenter/
%dir %{_kf6_sharedir}/plasma/kinfocenter/externalmodules/
%{_kf6_sharedir}/plasma/kinfocenter/externalmodules/kcm_external_plasma-systemmonitor.desktop
%dir %{_kf6_sharedir}/kglobalaccel/
%{_kf6_sharedir}/kglobalaccel/org.kde.plasma-systemmonitor.desktop

%files lang -f %{name}.lang

%changelog
* Tue Mar 11 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.3.3:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.3.3
- Changes since 6.3.2:
  * update version for new release
* Tue Feb 25 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.3.2:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.3.2
- Changes since 6.3.1:
  * update version for new release
* Tue Feb 18 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.3.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.3.1
- Changes since 6.3.0:
  * update version for new release
  * table: Fix row hovering with Qt 6.9+
  * update version for new release
  * faces/applications: Filter out applications with 0 processes
  * faces/applications: Use the memory column for application details
* Thu Feb  6 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.3.0:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.3.0
- Changes since 6.2.91:
  * update version for new release
  * Set interactive of TableView and page flickable to false (kde#499303,kde#487219)
* Thu Jan 23 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.91:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.91
- Changes since 6.2.90:
  * update version for new release
  * Don't show context menu in table view when right-clicking on nothing (kde#498672)
  * Always add widget to the first screen (kde#496768)
* Sat Jan 11 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.90:
  * New feature release
  * For more details see https://kde.org/announcements/plasma/6/6.2.90
- Too many changes to list here
* Tue Dec 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.5:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.5
- Changes since 6.2.4:
  * update version for new release
  * page: Fix rowSpacing for EditablePage contents
  * page: Replace EditablePage's OpacityAnimator with NumberAnimation
  * page: Hide new pages by default (kde#496875)
  * update version for new release
* Tue Nov 26 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.4:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.4
- Changes since 6.2.3:
  * update version for new release
  * EditablePage: Set loadOverlay margins explicitly, set loader invisible during loading (kde#494902)
  * BaseCellDelegate: Use correct colorSet when selected (kde#494261)
  * update version for new release
* Tue Nov  5 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.3:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.3
- Changes since 6.2.2:
  * update version for new release
* Tue Oct 22 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.2:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.2
- Changes since 6.2.1:
  * update version for new release
* Tue Oct 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.1
- Changes since 6.2.0:
  * update version for new release
* Sat Oct  5 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.2.0:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.2.0
- Changes since 6.1.90:
  * update version for new release
  * Add a missing screenshot
  * BaseTableView: Set pixelAligned to true (kde#493240)
* Tue Sep 17 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.90:
  * New feature release
  * For more details see https://kde.org/announcements/plasma/6/6.1.90
- Changes since 6.1.5:
  * update version for new release
  * Display signal type when SIGKILL'ing a process or application (kde#490934)
  * Fix opening About Page on Global Menu
  * faces/processtable: use sentence case in combobox
  * FaceConfigurationPage: use title case for actions
  * table: Fix default sort order when doing initial sort on a column (kde#490935)
  * TableViewHeader: remove from tab chain
  * use KF6Kirigami instead of KF6Kirigami2
  * Revert fix for the alternating background
  * Add option to allow a column to be hidden from the header
  * EditablePage: position loading placeholder overlay correctly (kde#488044)
  * appstream versions
  * Update the formatting of ColumnConfigurationDialog to better show the extent of the delegate while dragging. This is done by showing the highlight on the dragged item during the drag.
  * faces/FullRepresentation.qml: add minimum sizes (kde#487815)
  * Enable KCrash (kde#485891)
  * update version for new release
* Tue Sep 10 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.5:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.5
- Changes since 6.1.4:
  * update version for new release
  * table: Fix default sort order when doing initial sort on a column (kde#490935)
  * update version for new release
* Tue Aug  6 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.4:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.4
- Changes since 6.1.3:
  * update version for new release
  * TableViewHeader: remove from tab chain
* Tue Jul 16 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.3:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.3
- Changes since 6.1.2:
  * update version for new release
* Tue Jul  2 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.2:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.2
- Changes since 6.1.1:
  * update version for new release
* Tue Jun 25 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.1
- Changes since 6.1.0:
  * update version for new release
  * remove dup appstream version
  * update version for new release
  * EditablePage: position loading placeholder overlay correctly (kde#488044)
* Thu Jun 13 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.1.0:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.1.0
- Changes since 6.0.90:
  * update version for new release
  * appstream versions
  * update version for new release
  * faces/FullRepresentation.qml: add minimum sizes (kde#487815)
  * Enable KCrash (kde#485891)
* Sat May 25 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.90:
  * New feature release
  * For more details see https://kde.org/announcements/plasma/6/6.0.90
- Too many changes to list here
* Wed May 22 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.5:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.5
- Changes since 6.0.4:
  * remove dup version
  * update version for new release
  * FaceLoader: use qmlEngine for configEngine
  * applicationstable: Use FirstCellDelegate for the first cell in details table (kde#479235)
* Wed Apr 17 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.4:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.4
- Changes since 6.0.3:
  * update version for new release
  * Fix the column configuration dialog being too small on the overview page (kde#482008)
  * page: Store FaceController cache in QPointer (kde#482198)
  * revert premature appstream update
  * update version for new release
* Tue Mar 26 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.3:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.3
- Changes since 6.0.2:
  * revert duplicate appstream update
  * update version for new release
  * GlobalMenu: Fix path to AboutPage.qml
  * page: Fix drag-sorting of pages in PageSortDialog (kde#482377)
* Wed Mar 13 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.2:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.2
- Changes since 6.0.1:
  * update version for new release
* Wed Mar  6 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.1:
  * New bugfix release
  * For more details see https://kde.org/announcements/plasma/6/6.0.1
- Changes since 6.0.0:
  * update version for new release
* Mon Mar  4 2024 Christophe Marin <christophe@krop.fr>
- Add Provides/Obsoletes to replace Plasma 5
* Wed Feb 21 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.0:
  * New bugfix release
  * Release announcement not available yet
- Changes since 5.93.0:
  * update version for new release
  * table: Explicitly disable dragging beyond bounds in header (kde#481224)
  * page: Fix missing sensors display when not editing
  * Add a workaround for QTBUG-114999
  * table: Use upstream table selection behavior (kde#479329)
  * Only store window geometry if the window is in "Windowed" state (kde#478442)
  * page: Fix warning about signal parameter injection in FaceConfigurationPage
  * Slightly increase the width of the face configuration page
  * page: Properly constrain the size of config/sensors items in FaceConfigPage (kde#480986)
  * table: Ensure we update sortName when changing sort order (kde#480950)
  * Enable hover tooltips for entries in ColumnConfigurationDialog
  * Make face cache entries unique per-page (kde#480160)
  * table: Fix sorting of tables using the header (kde#479326)
  * update version for new release
* Wed Jan 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.93.0 (6.0 RC 2):
  * New bugfix release
  * See https://kde.org/announcements/megarelease/6/rc2/ for details
- Changes since 5.92.0:
  * Migrate existing system activity shortcut
  * Clip scrollable listviews (kde#479324)
* Wed Jan 17 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.92.0 (6.0 RC 1)
  * For more details please see:
    https://kde.org/announcements/megarelease/6/rc1/
* Fri Jul 14 2023 Christophe Marin <christophe@krop.fr>
- Init plasma6-systemmonitor
